package com.hrsk.pangu.dto;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;

/**
 * @author: bianlanzhou
 * @create: 2024-08-05 17:20
 * @description: copy from https://github.com/alibaba/COLA/tree/COLA4.3.2?tab=readme-ov-file
 *               适配了pageHelper
 **/
public class PageResponse<T> extends Response {

    private static final long serialVersionUID = 1L;
    private long totalCount = 0L;
    private long pageSize = 1L;
    private long pageIndex = 1L;
    private Collection<T> data;

    public PageResponse() {
    }

    public long getTotalCount() {
        return this.totalCount;
    }

    public void setTotalCount(long totalCount) {
        this.totalCount = totalCount;
    }

    public long getPageSize() {
        return Math.max(this.pageSize, 1L);
    }

    public void setPageSize(long pageSize) {
        this.pageSize = Math.max(pageSize, 1L);
    }

    public long getPageIndex() {
        return Math.max(this.pageIndex, 1L);
    }

    public void setPageIndex(long pageIndex) {
        this.pageIndex = Math.max(pageIndex, 1L);
    }

    public List<T> getData() {
        return (List)(this.data == null ? Collections.emptyList() : new ArrayList(this.data));
    }

    public void setData(Collection<T> data) {
        this.data = data;
    }

    public long getTotalPages() {
        return this.totalCount % this.pageSize == 0L ? this.totalCount / this.pageSize : this.totalCount / this.pageSize + 1L;
    }

    public boolean isEmpty() {
        return this.data == null || this.data.size() == 0;
    }

    public boolean isNotEmpty() {
        return !this.isEmpty();
    }

    public static PageResponse buildSuccess() {
        PageResponse response = new PageResponse();
        response.setSuccess(true);
        return response;
    }

    public static PageResponse buildFailure(String errCode, String errMessage) {
        PageResponse response = new PageResponse();
        response.setSuccess(false);
        response.setErrCode(errCode);
        response.setErrMessage(errMessage);
        return response;
    }

    public static <T> PageResponse<T> of(long pageSize, long pageIndex) {
        PageResponse<T> response = new PageResponse();
        response.setSuccess(true);
        response.setData(Collections.emptyList());
        response.setTotalCount(0L);
        response.setPageSize(pageSize);
        response.setPageIndex(pageIndex);
        return response;
    }

    public static <T> PageResponse<T> of(Collection<T> data, long totalCount, long pageSize, long pageIndex) {
        PageResponse<T> response = new PageResponse();
        response.setSuccess(true);
        response.setData(data);
        response.setTotalCount(totalCount);
        response.setPageSize(pageSize);
        response.setPageIndex(pageIndex);
        return response;
    }
}
